# Generated by Django 4.0.6 on 2022-08-10 11:13

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='userinfo',
            fields=[
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to=settings.AUTH_USER_MODEL)),
                ('phone', phonenumber_field.modelfields.PhoneNumberField(max_length=128, region=None)),
                ('address', models.CharField(default='none', max_length=25)),
            ],
            options={
                'verbose_name': 'User Advance Information',
                'verbose_name_plural': 'Profile Details',
            },
        ),
    ]



from django import forms
from django.contrib.auth.forms import UserCreationForm
from django.contrib.auth.models import User
from django.core.validators import RegexValidator


class SignUpForm(UserCreationForm):
    email = forms.EmailField(max_length=60, min_length=5, widget=forms.TextInput(attrs={'class': 'form-control',}))
    username = forms.CharField(max_length=50, validators=[RegexValidator('^[a-z0-9]+$', message='use small Letters and digits with minimum of 3 character')], min_length=3, help_text='use Letters and digits with minimum of 3 character',widget=forms.TextInput(attrs={'class': 'form-control'}))
    password1 = forms.CharField(label='Password', widget=forms.PasswordInput(attrs={'class': 'form-control'}))
    password2 = forms.CharField(label='Password confirmation', widget=forms.PasswordInput(attrs={'class': 'form-control'}))

    class Meta:
        model = User
        fields = ('username',  'email',)

    def clean_email(self):
        email = self.cleaned_data['email']
        if User.objects.filter(email__iexact=email).exists():
            raise forms.ValidationError('Email is Already Exists')
        return email
